# HTTP

To use this language, use the class "language-http".

## Request header

    GET http://localhost:9999/foo.html HTTP/1.1
    Accept-Language: fr,fr-fr;q=0.8,en-us;q=0.5,en;q=0.3
    Accept-Encoding: gzip, deflate

## Response header

    HTTP/1.1 200 OK
    Server: GitHub.com
    Date: Mon, 22 Dec 2014 18:25:30 GMT
    Content-Type: text/html; charset=utf-8

## Response body highlighted based on Content-Type

This currently supports the following content types : "application/json", "application/xml", "text/xml" and "text/html".

    HTTP/1.1 200 OK
    Server: GitHub.com
    Date: Mon, 22 Dec 2014 18:25:30 GMT
    Content-Type: text/html; charset=utf-8
    Last-Modified: Sun, 21 Dec 2014 20:29:48 GMT
    Transfer-Encoding: chunked
    Expires: Mon, 22 Dec 2014 18:35:30 GMT
    Cache-Control: max-age=600
    Vary: Accept-Encoding
    Content-Encoding: gzip

    <!DOCTYPE html>
    <html lang="en">
    <head></head>
    <body></body>
    </html>